==> qttranslations-opensource-src_5.4.1.orig.tar.xz: qttranslations-opensource-src-5.4.1/translations/qtscript_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>QScriptBreakpointsModel</name>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>Condition</source>
        <translation>Condició</translation>
    </message>
    <message>
        <source>Ignore-count</source>
        <translation>Ignora la quantitat</translation>
    </message>
    <message>
        <source>Single-shot</source>
        <translation>Només una vegada</translation>
    </message>
    <message>
        <source>Hit-count</source>
        <translation>Quantitat d&apos;assolits</translation>
    </message>
</context>
<context>
    <name>QScriptBreakpointsWidget</name>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
</context>
<context>
    <name>QScriptDebugger</name>
    <message>
        <source>Go to Line</source>
        <translation>Vés a la línia</translation>
    </message>
    <message>
        <source>Line:</source>
        <translation>Línia:</translation>
    </message>
    <message>
        <source>Interrupt</source>
        <translation>Interrupció</translation>
    </message>
    <message>
        <source>Shift+F5</source>
        <translation>Majús+F5</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Step Into</source>
        <translation>Passa a dins</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Step Over</source>
        <translation>Passa per sobre</translation>
    </message>
    <message>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <source>Step Out</source>
        <translation>Avança per fora</translation>
    </message>
    <message>
        <source>Shift+F11</source>
        <translation>Majús+F11</translation>
    </message>
    <message>
        <source>Run to Cursor</source>
        <translation>Executa fins al cursor</translation>
    </message>
    <message>
        <source>Ctrl+F10</source>
        <translation>Ctrl+F10</translation>
    </message>
    <message>
        <source>Run to New Script</source>
        <translation>Executa a un script nou</translation>
    </message>
    <message>
        <source>Toggle Breakpoint</source>
        <translation>Commuta el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <source>Clear Debug Output</source>
        <translation>Neteja la sortida de depuració</translation>
    </message>
    <message>
        <source>Clear Error Log</source>
        <translation>Neteja el registre d&apos;errors</translation>
    </message>
    <message>
        <source>Clear Console</source>
        <translation>Neteja la consola</translation>
    </message>
    <message>
        <source>&amp;Find in Script...</source>
        <translation>&amp;Troba a l&apos;script</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Cerca el se&amp;güent</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Cerca l&apos;a&amp;nterior</translation>
    </message>
    <message>
        <source>Shift+F3</source>
        <translation>Majús+F3</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depura</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerCodeFinderWidget</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Distingeix entre majúscules i minúscules</translation>
    </message>
    <message>
        <source>Whole words</source>
        <translation>Paraules senceres</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt/scripttools/debugging/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt/scripttools/debugging/images/wrap.png&quot;&gt;&amp;nbsp;Cerca embolcallada</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerLocalsModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerStackModel</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
</context>
<context>
    <name>QScriptEdit</name>
    <message>
        <source>Toggle Breakpoint</source>
        <translation>Commuta el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Disable Breakpoint</source>
        <translation>Desactiva el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Enable Breakpoint</source>
        <translation>Activa el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Breakpoint Condition:</source>
        <translation>Condició del punt d&apos;interrupció:</translation>
    </message>
</context>
<context>
    <name>QScriptEngineDebugger</name>
    <message>
        <source>Loaded Scripts</source>
        <translation>Scripts carregats</translation>
    </message>
    <message>
        <source>Breakpoints</source>
        <translation>Punts d&apos;interrupció</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Locals</source>
        <translation>Locals</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Consola</translation>
    </message>
    <message>
        <source>Debug Output</source>
        <translation>Sortida de depuració</translation>
    </message>
    <message>
        <source>Error Log</source>
        <translation>Registre d&apos;errors</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Qt Script Debugger</source>
        <translation>Depurador d&apos;scripts de Qt</translation>
    </message>
</context>
<context>
    <name>QScriptNewBreakpointWidget</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
</TS>

==> qttranslations-opensource-src_5.5.1.orig.tar.xz: qttranslations-opensource-src-5.5.1/translations/qtscript_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>QScriptBreakpointsModel</name>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
    <message>
        <source>Condition</source>
        <translation>Condició</translation>
    </message>
    <message>
        <source>Ignore-count</source>
        <translation>Ignora la quantitat</translation>
    </message>
    <message>
        <source>Single-shot</source>
        <translation>Només una vegada</translation>
    </message>
    <message>
        <source>Hit-count</source>
        <translation>Quantitat d&apos;assolits</translation>
    </message>
</context>
<context>
    <name>QScriptBreakpointsWidget</name>
    <message>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
</context>
<context>
    <name>QScriptDebugger</name>
    <message>
        <source>Go to Line</source>
        <translation>Vés a la línia</translation>
    </message>
    <message>
        <source>Line:</source>
        <translation>Línia:</translation>
    </message>
    <message>
        <source>Interrupt</source>
        <translation>Interrupció</translation>
    </message>
    <message>
        <source>Shift+F5</source>
        <translation>Majús+F5</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>Step Into</source>
        <translation>Passa a dins</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Step Over</source>
        <translation>Passa per sobre</translation>
    </message>
    <message>
        <source>F10</source>
        <translation>F10</translation>
    </message>
    <message>
        <source>Step Out</source>
        <translation>Avança per fora</translation>
    </message>
    <message>
        <source>Shift+F11</source>
        <translation>Majús+F11</translation>
    </message>
    <message>
        <source>Run to Cursor</source>
        <translation>Executa fins al cursor</translation>
    </message>
    <message>
        <source>Ctrl+F10</source>
        <translation>Ctrl+F10</translation>
    </message>
    <message>
        <source>Run to New Script</source>
        <translation>Executa a un script nou</translation>
    </message>
    <message>
        <source>Toggle Breakpoint</source>
        <translation>Commuta el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>F9</source>
        <translation>F9</translation>
    </message>
    <message>
        <source>Clear Debug Output</source>
        <translation>Neteja la sortida de depuració</translation>
    </message>
    <message>
        <source>Clear Error Log</source>
        <translation>Neteja el registre d&apos;errors</translation>
    </message>
    <message>
        <source>Clear Console</source>
        <translation>Neteja la consola</translation>
    </message>
    <message>
        <source>&amp;Find in Script...</source>
        <translation>&amp;Cerca en l&apos;script...</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Cerca el se&amp;güent</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Cerca l&apos;a&amp;nterior</translation>
    </message>
    <message>
        <source>Shift+F3</source>
        <translation>Majús+F3</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depura</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerCodeFinderWidget</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Distingeix entre majúscules i minúscules</translation>
    </message>
    <message>
        <source>Whole words</source>
        <translation>Paraules senceres</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt/scripttools/debugging/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt/scripttools/debugging/images/wrap.png&quot;&gt;&amp;nbsp;Cerca embolcallada</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerLocalsModel</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>QScriptDebuggerStackModel</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Ubicació</translation>
    </message>
</context>
<context>
    <name>QScriptEdit</name>
    <message>
        <source>Toggle Breakpoint</source>
        <translation>Commuta el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Disable Breakpoint</source>
        <translation>Desactiva el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Enable Breakpoint</source>
        <translation>Activa el punt d&apos;interrupció</translation>
    </message>
    <message>
        <source>Breakpoint Condition:</source>
        <translation>Condició del punt d&apos;interrupció:</translation>
    </message>
</context>
<context>
    <name>QScriptEngineDebugger</name>
    <message>
        <source>Loaded Scripts</source>
        <translation>Scripts carregats</translation>
    </message>
    <message>
        <source>Breakpoints</source>
        <translation>Punts d&apos;interrupció</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Pila</translation>
    </message>
    <message>
        <source>Locals</source>
        <translation>Locals</translation>
    </message>
    <message>
        <source>Console</source>
        <translation>Consola</translation>
    </message>
    <message>
        <source>Debug Output</source>
        <translation>Sortida de depuració</translation>
    </message>
    <message>
        <source>Error Log</source>
        <translation>Registre d&apos;errors</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <source>Qt Script Debugger</source>
        <translation>Depurador d&apos;scripts de Qt</translation>
    </message>
</context>
<context>
    <name>QScriptNewBreakpointWidget</name>
    <message>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
</TS>
